<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>Gestor de usuarios de MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administración</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Agregar un usuario nuevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Agregar una Cuenta de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Escriba de nuevo la contraseña para el nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>confirmar contraseña</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Nombre de usuario del nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Nombre de ingreso del usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Ingrese el nombre del nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>nombre del usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Contraseña para el usuario nuevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Contraseña del usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Ingrese la contraseña para el nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>contraseña</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Confirmar contraseña de usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Borrar una Cuenta de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Elegir usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Seleccionar usuario para eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Usuario a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Borrar también el directorio home del usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Borrar el directori home del usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation>Renombrar la Cuenta de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Escoger usuario para modificar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation>Nuevo nombre de usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Cambiar Contraseña de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>nueva contraseña</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>Confirmar nueva contraseña:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>Confirmar nueva contraseña</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Nueva contraseña de usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Reparar la configuración de un usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Modificar la Cuenta de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Seleccione el usuario a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Usuario a cambiar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Restaurar los ajustes por defecto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Restaurar el navegador a la configuración por defecto en MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configuración de Mozilla (Iceweasel o Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Restaurar las membresías a las de los grupos por defecto en MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Membresías de los grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Cambiar los ajustes del ingreso automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Ingresar automáticamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Solicitar contraseña para ingresar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Copiar/Sincronizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Copiar escritorios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Seleccione el escritorio a copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Seleccionar para copiar archivos solamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Copiado solamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Seleccione el escritorio en el cual copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Copiar en:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Copiar de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Seleccionar copiar y luego borrar las diferencias</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Sincronización</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Seleccionar para copia/sincronización compartida </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Carpeta compartida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Seleccionar para copia/sincronización completa del directorio home </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Todo home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Seleccione para copiar/sincronizar la configuración del navegador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Configuración de Mozilla (Firefox o Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Seleccionar para copiar/sincronizar Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Carpeta Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>Elementos a copiar/sincronizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Estado de los cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Progreso de los cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Agregar/Remover Grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Agregar un Grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Nombre del Grupo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>nombredelgrupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Borrar grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Grupo a borrar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Membresía del grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Grupos a los que el usuario pertenece (cambie los grupos seleccionando/deseleccionando las cajas apropiadas):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>*Por favor revise sus selecciones antes de aplicarlas; las membresías erróneas a los grupos pueden dañar su sistema.  Use la pestaña Reparar para restaurar las membresías originales en caso de haber cometido un error. </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Aplicar los cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar los cambios y luego salir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <location filename="../mainwindow.cpp" line="135"/>
        <location filename="../mainwindow.cpp" line="143"/>
        <location filename="../mainwindow.cpp" line="156"/>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="176"/>
        <location filename="../mainwindow.cpp" line="185"/>
        <location filename="../mainwindow.cpp" line="602"/>
        <location filename="../mainwindow.cpp" line="618"/>
        <location filename="../mainwindow.cpp" line="646"/>
        <location filename="../mainwindow.cpp" line="654"/>
        <location filename="../mainwindow.cpp" line="787"/>
        <location filename="../mainwindow.cpp" line="898"/>
        <source>none</source>
        <translation>ninguno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="194"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Se reparará la configuración del usuario.  Por favor cierre ahora todas las demás aplicaciones y, al terminar, reinicie la sesión o el equipo. ¿Está seguro de que desea efectuar la reparación en este momento?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>User group membership was restored.</source>
        <translation>La membresía de los grupos del usuario fue restaurada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="220"/>
        <source>Mozilla settings were reset.</source>
        <translation>La configuración de Mozilla se restableció.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="229"/>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Autologin options</source>
        <translation>Opciones de ingreso automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>El ingreso automático se desactivó para la cuenta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>El ingreso automático se activó para la cuenta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Debe especificar un destino en &quot;copiar a&quot;. No se puede copiar al escritorio activo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Antes de copiar, cierre todas las otras aplicaciones.  Asegúrese de que el destino al que va a copiar posea suficiente espacio para los archivos a copiarse.  Copiar los escritorios puede reescribir o borrar sus archivos y preferencias en el escritorio de destino. ¿En verdad desea proceder? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Synchronizing desktop...</source>
        <translation>Sincronizando el escritorio...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Copying desktop...</source>
        <translation>Copiando el escritorio...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <location filename="../mainwindow.cpp" line="492"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>El nombre de usuario debe ser de al menos 2 caracteres. Por favor seleccione un nombre más largo antes de proceder.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>El nombre del usuario debe estar en minúscula
y no puede incluir espacios o caracteres especiales.
Escoja otro antes de continuar, por favor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Lo sentimos, este nombre está en uso. Por favor ingrese un nombre diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Claves introducidas no concuerdan. Favor intente de nuevo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <location filename="../mainwindow.cpp" line="357"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Contraseña debe que tener mínimo 2 caracteres. Favor coloque una más larga antes de proceder. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>The user was added ok.</source>
        <translation>Se agregó con éxito el usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Failed to add the user.</source>
        <translation>No se pudo agregar el usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Password successfully changed.</source>
        <translation>Clave cambiado con éxito. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Failed to change password.</source>
        <translation>Fallo en cambiar clave. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Esta acción no se puede deshacer. ¿Desea realmente borrar al usuario %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>The user has been deleted.</source>
        <translation>Se ha borrado el usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="397"/>
        <source>Failed to delete the user.</source>
        <translation>No se pudo borrar el usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>El nombre del grupo debe ser de al menos 2 caracteres.  Por favor, seleccione uno más largo antes de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>El nombre del grupo debe estar en minúscula 
y no puede incluir espacios o caracteres especiales.
Escoja otro antes de continuar, por favor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Lo sentimos, ese nombre de grupo ya existe. Por favor ingrese un nombre diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>The system group was added ok.</source>
        <translation>El grupo se agregó con éxito al sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Failed to add the system group.</source>
        <translation>No se pudo agregar el grupo al sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Esta acción no se puede deshacer. ¿Desea realmente borrar el grupo %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>The group has been deleted.</source>
        <translation>Se ha borrado el grupo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Failed to delete the group.</source>
        <translation>No se pudo borrar el grupo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>The changes have been applied.</source>
        <translation>Se aplicaron todos los cambios.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>Failed to apply group changes</source>
        <translation>No se pudo aplicar los cambios a los grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>The selected user name is currently in use.</source>
        <translation>El nombre de usuario seleccionado está actualmente en uso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Para renombrar este usuario, cierre la sesión y vuelva a iniciarla con otra cuenta de usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Lo sentimos, este nombre ya existe en su sistema. Por favor ingrese un nombre diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Error al renombrar el usuario. Asegúrese que el usuario no haya iniciado sesión, es posible que deba reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>The user was renamed.</source>
        <translation>El usuario fue renombrado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sincronizando el escritorio...OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Copying desktop...ok</source>
        <translation>Copiando el escritorio...OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="577"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sincronizando el escritorio...falló</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>Copying desktop...failed</source>
        <translation>Copiando el escritorio...falló</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="596"/>
        <location filename="../mainwindow.cpp" line="838"/>
        <location filename="../mainwindow.cpp" line="846"/>
        <source>browse...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="752"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="753"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Configuración simple de usuarios para MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="756"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="770"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Select folder to copy to</source>
        <translation>Seleccione carpeta en donde copiar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Debe ejecutar este programa como root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
